@@ -1,4 +1,4 @@
 DATA_DIR = "/usr/local/share"
-LIB_DIR = "/usr/local/lib"
-VERSION = "2.27.90"
+LIB_DIR = "/usr/local/libexec"
+VERSION = "2.27.91"
 PACKAGE = "deskbar-applet"
